pstore :: Python Protected Password Store
=========================================

The list of changes.

2013-07-31: 1.0
---------------
 * Move to github.

2013-07-31: 0.96
----------------
 * Fix bug with stdin not ending after a single CTRL+D.
 * Improve readability of Markdown files.
 * Clean up documentation, fix unit tests.
 * Allow the integration test to use an already running django-pstore.
   This aids in debugging problems.
 * Document how Large File issues may be solved.
 * Take version info from the CHANGES.md.
 * Use a single version number all over the project.

2013-04-15: 0.95rc4
-------------------
 * There was no changelog.
 * vim: set syntax=markdown tw=72:
